
# Type: slot_definition_apply_to




URI: [meta:slot_definition_apply_to](https://w3id.org/biolink/biolinkml/meta/slot_definition_apply_to)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>0..*</sub> [SlotDefinition](SlotDefinition.md)

## Parents

 *  is_a: [apply_to](apply_to.md)

## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
